.. _api:

List of functions and classes (API)
===================================

.. automodule:: inversiontestproblems

.. attention::

    This package is still under initial development stage, so public APIs are
    not expected to be stable. Please stay updated and don't hesitate to raise
    feedback or issues through `GitHub issues <https://github.com/inlab-geo/cofi/issues/new/choose>`_
    or `Slack workspace <https://inlab-geo.slack.com>`_.

APIs for Basic Usage
--------------------

This is a placeholder text until a proper one is written.



.. autosummary::
    :toctree: generated/
    :nosignatures:

    gravityforward
    
